@@ -94,11 +94,9 @@
     clippy::no_effect
 )]
 
-// TODO: add rust-version to [package]
-// TODO: run cargo outdated when it is fixed for stable 1.56
-// TODO: maybe refactor read internal to include ::std::cmp::min() -> min(buf.len(), state.data.len()) 
-// buf[..n].copy_from_slice(data[..n]) see 1:13:41
-// TODO: reorder all structs and impl blocks in crate
+// TODO: add rust-version to [package] (atm 1.56.1)
+// TODO: run cargo outdated when it is fixed for stable 1.56 (0.9.17)
+// TODO: maybe include https://deps.rs/repo/github/jimvdl/rs-cache, need to swap to memmap replacement because it is insecure
  
 #[macro_use]
 pub mod util;
@@ -118,11 +116,12 @@ pub use error::{CacheError, Result};
 
 pub(crate) const MAIN_DATA: &str = "main_file_cache.dat2";
 pub(crate) const REFERENCE_TABLE: u8 = 255;
+const CRC: Crc<u32> = Crc::<u32>::new(&CRC_32_ISO_HDLC);
 
 use std::{fs::File, io::Write, path::Path};
 
-use crc::crc32;
-use memmap::Mmap;
+use crc::{Crc, CRC_32_ISO_HDLC};
+use memmap2::Mmap;
 use nom::{combinator::cond, number::complete::be_u32};
 #[cfg(feature = "rs3")]
 use whirlpool::{Digest, Whirlpool};
@@ -255,8 +254,11 @@ impl Cache {
                         hasher.finalize().as_slice().to_vec()
                     };
 
+                    let mut digest = CRC.digest();
+                    digest.update(&buffer);
+
                     checksum.push(Entry {
-                        crc: crc32::checksum_ieee(&buffer),
+                        crc: digest.finalize(),
                         version,
                         #[cfg(feature = "rs3")]
                         hash,
